@@ -11,52 +11,59 @@
 #' @template as_data_frame
 #' @template showProgress
 #' @template cache
+#' @template verbose
 #'
 #' @return An arrow `Dataset` or a `"data.frame"` object.
 #' @export
 #' @family Microdata
 #' @examplesIf identical(tolower(Sys.getenv("NOT_CRAN")), "true")
 #' # return data as arrow Dataset
-#' df <- read_emigration(year = 2010,
-#'                       showProgress = FALSE)
-#'
+#' df <- read_emigration(
+#'   year = 2010,
+#'   showProgress = FALSE
+#'   )
 #'
 #' # return data as data.frame
-#' df <- read_emigration(year = 2010,
-#'                       as_data_frame = TRUE,
-#'                       showProgress = FALSE)
+#' df <- read_emigration(
+#'   year = 2010,
+#'   as_data_frame = TRUE,
+#'   showProgress = FALSE
+#'   )
 #'
 #'
-read_emigration <- function(year = 2010,
+read_emigration <- function(year,
                             columns = NULL,
                             add_labels = NULL,
                             merge_households = FALSE,
                             as_data_frame = FALSE,
                             showProgress = TRUE,
-                            cache = TRUE){
+                            cache = TRUE,
+                            verbose = TRUE){
 
   ### check inputs
-  checkmate::assert_numeric(year)
+  checkmate::assert_numeric(year, any.missing = FALSE)
   checkmate::assert_vector(columns, null.ok = TRUE)
-  checkmate::assert_logical(as_data_frame)
-  checkmate::assert_logical(merge_households)
+  checkmate::assert_logical(as_data_frame, null.ok = FALSE)
+  checkmate::assert_logical(merge_households, null.ok = FALSE)
+  checkmate::assert_logical(verbose, null.ok = FALSE)
   checkmate::assert_string(add_labels, pattern = 'pt', null.ok = TRUE)
 
   # data available for the years:
   years <- c(2010)
-  if (isFALSE(year %in% years)) { stop(paste0("Error: Data currently only available for the years ",
-                                              paste(years, collapse = " ")))}
+  if (isFALSE(year %in% years)) {
+    error_missing_years(years)
+    }
 
   ### Get url
   file_url <- paste0("https://github.com/ipeaGIT/censobr/releases/download/",
                      censobr_env$data_release, "/", year, "_emigration_",
                      censobr_env$data_release, ".parquet")
 
-
   ### Download
   local_file <- download_file(file_url = file_url,
                               showProgress = showProgress,
-                              cache = cache)
+                              cache = cache,
+                              verbose = verbose)
 
   # check if download worked
   if(is.null(local_file)) { return(invisible(NULL)) }
@@ -69,7 +76,8 @@ read_emigration <- function(year = 2010,
     df <- merge_household_var(df,
                               year = year,
                               add_labels = add_labels,
-                              showProgress)
+                              showProgress = showProgress,
+                              verbose = verbose)
   }
 
   ### Select
