@@ -4,40 +4,46 @@
 #' Download microdata of family records from Brazil's census. Data collected in
 #' the sample component of the questionnaire.
 #'
-#' @param year Numeric. Year of reference in the format `yyyy`. Defaults to `2000`.
+#' @template year
 #' @template columns
 #' @template add_labels
 #' @template as_data_frame
 #' @template showProgress
 #' @template cache
+#' @template verbose
 #'
 #' @return An arrow `Dataset` or a `"data.frame"` object.
 #' @export
 #' @family Microdata
 #' @examplesIf identical(tolower(Sys.getenv("NOT_CRAN")), "true")
 #' # return data as arrow Dataset
-#' df <- read_families(year = 2000,
-#'                     showProgress = FALSE)
+#' df <- read_families(
+#'   year = 2000,
+#'   showProgress = FALSE
+#'   )
 #'
 #'
-read_families <- function(year = 2000,
+read_families <- function(year,
                           columns = NULL,
                           add_labels = NULL,
                           as_data_frame = FALSE,
                           showProgress = TRUE,
-                          cache = TRUE){
+                          cache = TRUE,
+                          verbose = TRUE){
 
   ### check inputs
-  checkmate::assert_numeric(year)
+  checkmate::assert_numeric(year, any.missing = FALSE)
   checkmate::assert_vector(columns, null.ok = TRUE)
-  checkmate::assert_logical(as_data_frame)
+  checkmate::assert_logical(as_data_frame, null.ok = FALSE)
+  checkmate::assert_logical(verbose, null.ok = FALSE)
   # checkmate::assert_logical(merge_households)
   checkmate::assert_string(add_labels, pattern = 'pt', null.ok = TRUE)
 
   # data available for the years:
   years <- c(2000)
-  if (isFALSE(year %in% years)) { stop(paste0("Error: Data currently only available for the years ",
-                                              paste(years, collapse = " ")))}
+  if (isFALSE(year %in% years)) {
+    error_missing_years(years)
+    }
 
   ### Get url
   file_url <- paste0("https://github.com/ipeaGIT/censobr/releases/download/",
@@ -48,7 +54,8 @@ read_families <- function(year = 2000,
   ### Download
   local_file <- download_file(file_url = file_url,
                               showProgress = showProgress,
-                              cache = cache)
+                              cache = cache,
+                              verbose = verbose)
 
   # check if download worked
   if(is.null(local_file)) { return(invisible(NULL)) }
