@@ -16,10 +16,11 @@ test_that("interview_manual", {
   testthat::expect_message( interview_manual(year = 1991, showProgress = FALSE) )
   testthat::expect_message( interview_manual(year = 1980, showProgress = FALSE) )
   testthat::expect_message( interview_manual(year = 1970, showProgress = FALSE) )
+  testthat::expect_no_message( interview_manual(year = 1970, verbose = FALSE) )
 
   # cache dir
-  pkgv <- paste0('censobr/data_release_', censobr_env$data_release)
-  cache_dir <- tools::R_user_dir(pkgv, which = 'cache')
+  pkgv <- paste0('data_release_', censobr_env$data_release)
+  cache_dir <- fs::path(get_censobr_cache_dir(), pkgv)
 
   ## check if file have been downloaded
   years <- c(1970, 1980, 1991, 2000, 2010, 2022)
@@ -39,6 +40,8 @@ test_that("interview_manual", {
   testthat::expect_error(interview_manual(year = 9999))
   testthat::expect_error(interview_manual(year = 2000, showProgress = 'banana'))
   testthat::expect_error(interview_manual(year = 2000, cache = 'banana'))
+  testthat::expect_error(interview_manual(year = 2000, verbose = 'banana'))
+
 })
 
 
