@@ -12,15 +12,18 @@ test_that("add_labels_households", {
 
   ################################################################### 2010
   # sem labels
-  test1a <- read_households(year = 2010, add_labels = NULL, columns = c('abbrev_state', 'V1006')) |>
-            filter(abbrev_state == 'RO')
+  test1a <- read_households(year = 2010,
+                            add_labels = NULL,
+                            columns = c('abbrev_state', 'V1006'),
+                            showProgress = FALSE) |>
+            dplyr::filter(abbrev_state == 'RO')
 
   # com labels
   test1b <- censobr:::add_labels_households(arrw = test1a, year=2010, lang = 'pt') |>
-            filter(abbrev_state == 'RO')
+            dplyr::filter(abbrev_state == 'RO')
 
-  test1a <- as.data.frame(test1a)
-  test1b <- as.data.frame(test1b)
+  test1a <- dplyr::collect(test1a)
+  test1b <- dplyr::collect(test1b)
 
   # add labels
   testthat::expect_true('1' %in% test1a$V1006)
@@ -30,15 +33,20 @@ test_that("add_labels_households", {
 
   ################################################################### 2000
   # sem labels
-  test2a <- read_households(year = 2000, add_labels = NULL) |>
-    filter(abbrev_state == 'RO')
+  test2a <- read_households(year = 2000,
+                            add_labels = NULL,
+                            columns = c('abbrev_state', 'V1006'),
+                            showProgress = FALSE) |>
+    dplyr::filter(abbrev_state == 'RO')
 
   # com labels
-  test2b <- censobr:::add_labels_households(arrw = test2a, year=2000, lang = 'pt') |>
-    filter(abbrev_state == 'RO')
+  test2b <- censobr:::add_labels_households(arrw = test2a,
+                                            year=2000,
+                                            lang = 'pt') |>
+    dplyr::filter(abbrev_state == 'RO')
 
-  test2a <- as.data.frame(test2a)
-  test2b <- as.data.frame(test2b)
+  test2a <- dplyr::collect(test2a)
+  test2b <- dplyr::collect(test2b)
 
   # add labels
   testthat::expect_true('1' %in% test2a$V1006)
